It's easy!

#. Go to the front page or click on New_ in the page header.

#. Write or copy-and-paste something in the big text area.

#. Hit ``TAB`` to go to the next field and optionally give a title.

#. Hit ``TAB`` to go to the  select field and choose the format for syntax
   highlighting or leave it at the default ("Text only", i.e. no highlighting).

#. Hit ``TAB`` again and then ``RETURN`` to submit your paste.

#. Copy the URL from the browser address bar and paste it into an email,
   forum post, instant messenger, whatever ...

   ... or click the "Send link" link in the page header to open a new email with
   your standard email program with the subject pre-filled and the paste link
   already inserted in the message body.

.. _new: /new
